/* Portwatch                               *
 * Mark Kamichoff [kamicm@rpi.edu]         *
 * logmanip.h - Some useful functions that *
 * make writing (and maybe reading) to     *
 * portwatch log files easier (and kind-of *
 * standardized to a certain extent        *
 * [01/04/02]                              */

#ifndef LOGMANIP_H_
#define LOGMANIP_H_

#define MAXSIZE 80

/* Returns 0 if ok, -1 on error */
int keeplog(int, char *, unsigned long, char *);

int keeplog(int fd, char *ipaddy, unsigned long portnum, char *hostname)
{
	FILE *logfd;
	char buffer[MAXSIZE];
	int bytes;
	time_t ticks;

	ticks = time(NULL);     /* Get Current Time */
	logfd = fopen(ipaddy,"a");	/* Open [ipaddress] file */

	if(!logfd)
		return 1;	/* Some error opening file */
				/* Permission denied or slice at capacity */

	/* Output that client connected to LOG */
	fputs("@Connect: ",logfd);
	fputs(hostname,logfd);
	fputs(":",logfd);
//	fputs(tempport,logfd);
	fprintf(logfd,"%d",portnum);
	fputs(" [",logfd);
	fputs(ipaddy,logfd);
	fputs("] at ",logfd);
	fputs(ctime(&ticks),logfd);

	/* Write stuff to file */
	while((bytes = read(fd, buffer, strlen(buffer))) != 0)
	{
		buffer[bytes] = 0;	/* NULL terminator */
		fputs(buffer,logfd);	/* fixit! */
	}		

	ticks = time(NULL);     /* Get Current Time */

	/* Output that client disconnected to console */
	printf("Disconnect: %s:%ld [%s] at %.24s\r\n",
		hostname,portnum,ipaddy,ctime(&ticks));

	/* Output that client disconnected to LOG */
	fputs("@Disconnect: ",logfd);
	fputs(hostname,logfd);
	fputs(":",logfd);
//	fputs((char *)portnum,logfd);
	fprintf(logfd,"%d",portnum);
	fputs(" [",logfd);
	fputs(ipaddy,logfd);
	fputs("] at ",logfd);
	fputs(ctime(&ticks),logfd);

	fclose(logfd);

	return 0;	/* fixit! */
}

#endif
